/* tslint:disable */
/* eslint-disable */
/**
*/
export class PQueue {
  free(): void;
/**
* Construct a new priority queue.
* 
* If the `order` is "asc" then it's a ascending priority queue.
* If the `order` is "desc" then it's a descending priority queue.
* Otherwise, it throws a exception.
* @param {string} order
*/
  constructor(order: string);
/**
* Insert a key in the priority queue.
*
* The method assumes that there is no data associated with the inserted key.
* @param {number | undefined} key_op
*/
  insertK(key_op?: number): void;
/**
* Insert a key in the priority queue. `insertKV` stands for `insert key and value`.
*
* The `value` should be any data associated with the inserted key.
* @param {number | undefined} key_op
* @param {any} value
*/
  insertKV(key_op: number | undefined, value: any): void;
/**
* Insert a array of keys in the priority queue. This method is roughly equivalent for calling `insert_k` for each element of the array `keys`, but it's more faster. 
*
* This method is more faster than calling `insert_k` for each key, because using this method just only one call to webassembly happens.
* @param {any[]} keys
*/
  bulkInsertK(keys: any[]): void;
/**
* Insert a array of keys in the priority queue with associated values. The value `values[0]` is associated with the key `keys[0]`, and so on.
* This method is roughly equivalent for calling `insert_kv` for each element of the two array `keys` and `values`, but it's more faster. 
*
* Both array must have the same length, otherwise, an error is thrown.
* @param {any[]} keys
* @param {any[]} values
*/
  bulkInsertKV(keys: any[], values: any[]): void;
/**
* Pop from the queue the pair key/value with higher priority.
*
* Returns a array which the first element is the key.
* The returned array have the length 2 if the key has inserted with associated data.
* If the key has inserted without any associated data, it returns a array with a single element.
* @returns {Array<any>}
*/
  popKV(): Array<any>;
/**
* Pop from the queue the key with higher priority.
* @returns {number}
*/
  popK(): number;
/**
* Return a array with the keys with highest priority. The returned keys are removed from the Queue.
* 
* The `quantity_op` is the number of elements to be returned.
* This methods is more faster than calling `pop_k` repeatedly for popping a sequence of keys.
* @param {number | undefined} quantity_op
* @returns {Float64Array}
*/
  bulkPopK(quantity_op?: number): Float64Array;
/**
* Return an array with the the pairs key/value with highest priority. The returned pairs are removed from the Queue.
* 
* Each element of the returned array is like the returned element of `pop_kv`, so it's a array with two or one element.
* This methods is more faster than calling `pop_kv` repeatedly for popping a sequence of key/value.
* @param {number | undefined} quantity_op
* @returns {(Array<any>)[]}
*/
  bulkPopKV(quantity_op?: number): (Array<any>)[];
/**
* Return the key with higher priority without remove it
* @returns {number}
*/
  topK(): number;
/**
* Return the pair key/value with higher priority without remove it
*
* Returns a array which the first element is the key.
* The returned array have the length 2 if the key has inserted with associated data.
* If the key has inserted without any associated data, it returns a array with a single element.
* @returns {Array<any>}
*/
  topKV(): Array<any>;
/**
* The number of keys in the queue.
*/
  readonly length: number;
}
